"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateItem = void 0;
const validateItem = (item) => {
    const validators = [
        validateItemTitle,
        validateItemRawBody,
        validateItemTags,
        validateLengthItemTags,
        validateOrganizationSecretItem,
    ];
    return getValidationErrorMessages(item, validators);
};
exports.validateItem = validateItem;
const validateItemTitle = {
    getMessage: () => "タイトルを入力してください",
    isValid: ({ title }) => {
        if (!title)
            return false;
        return title.length > 0;
    },
};
const validateItemRawBody = {
    getMessage: () => "本文を入力してください",
    isValid: ({ rawBody }) => {
        if (!rawBody)
            return false;
        return rawBody.length > 0;
    },
};
const validateItemTags = {
    getMessage: () => "タグを入力してください",
    isValid: ({ tags }) => {
        return Array.isArray(tags) && tags.every((value) => value !== "");
    },
};
const validateLengthItemTags = {
    getMessage: () => "タグは1つ以上、5つ以内で指定してください",
    isValid: ({ tags }) => {
        return 0 < tags.length && tags.length <= 5;
    },
};
const validateOrganizationSecretItem = {
    getMessage: () => "限定共有記事にOrganizationを紐付けることはできません",
    isValid: ({ organizationUrlName, secret }) => {
        if (secret && organizationUrlName)
            return false;
        return true;
    },
};
const getValidationErrorMessages = (item, validators) => {
    return validators.reduce((errorMessages, validator) => {
        if (!validator.isValid(item)) {
            errorMessages.push(validator.getMessage(item));
        }
        return errorMessages;
    }, []);
};
//# sourceMappingURL=item-validator.js.map